local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables
local talent = x.Talent
local variable = x.Variables
local action = x.Action
local dot = x.Dot
local target = x.Target
local buff = x.Buff
local cooldown = x.Cooldown
local azerite = x.Azerite
local prev_gcd = x.PrevGCD

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.EnemyDetected, x.EnemyDetected, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable

-- Example flash color coding:
-- White - Default
-- Yellow - Limited Time or No Global Cooldown
-- Purple - AOE or Positional Damage
-- Blue - AOE Debuff
-- Orange - Finishing Move
-- Aqua - Spell Interrupt, Reflect or Dispel
-- Green - Self Buff or Turn Autocast On
-- Red - Emergency Mitigation Cooldowns or Turn Autocast Off
-- Pink - Optional

a.spells["flask_balance"] = {
	Type = "item",
	ID = 152639--[[Flask of Endless Fathoms]],
	Buff = 251837--[[Flask of Endless Fathoms]],
	BuffUnit = "player",
	FlashColor = "Green",
	CheckFirst = function(z)
		return s.Boss("target")
	end,
}

a.spells["potion_balance"] = {
	Type = "item",
	ID = 152559--[[Potion of Rising Death]],
	Buff = 269853--[[Potion of Rising Death]],
	BuffUnit = "player",
	NoGCD = true,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.InCombat, "Yellow", "Green")
		return s.Boss("target")
	end,
	FlashID = {
		152559--[[Potion of Rising Death]],
		163222--[[Battle Potion of Intellect]],
	},
}

a.spells["solar_beam"] = {
	ID = 78675--[[Solar Beam]],
	EnemyTargetNeeded = true,
	Interrupt = true,
	NoRangeCheck = true,
	NoGCD = true,
	FlashColor = "Aqua",
}

a.spells["moonkin_form"] = {
	Type = "form",
	ID = 24858--[[Moonkin Form]],
	Buff = 24858--[[Moonkin Form]],
	BuffUnit = "player",
	FlashColor = "Green",
}

a.spells["solar_wrath"] = {
	ID = 190984--[[Solar Wrath]],
}

a.spells["potion,if=buff.ca_inc.remains>6&active_enemies=1"] = {
	Type = "item",
	ID = 152559--[[Potion of Rising Death]],
	Buff = 269853--[[Potion of Rising Death]],
	BuffUnit = "player",
	NoGCD = true,
	CheckFirst = function(z)
		return s.Boss("target") and buff.ca_inc.remains_nogcd > 6 and x.ActiveEnemies == 1
	end,
	FlashID = {
		152559--[[Potion of Rising Death]],
		163222--[[Battle Potion of Intellect]],
	},
}

a.spells["potion,name=battle_potion_of_intellect,if=buff.ca_inc.remains>6"] = {
	Type = "item",
	ID = 163222--[[Battle Potion of Intellect]],
	Buff = 279151--[[Battle Potion of Intellect]],
	BuffUnit = "player",
	NoGCD = true,
	CheckFirst = function(z)
		return s.Boss("target") and buff.ca_inc.remains_nogcd > 6
	end,
}

a.spells["berserking,if=buff.ca_inc.up"] = {
	ID = 26297--[[Berserking]],
	Check = function(z)
		return buff.ca_inc.up_nogcd
	end,
	FlashColor = "Yellow",
	NoGCD = true,
}

--			,"use_item,name=balefire_branch,if=equipped.159630&cooldown.ca_inc.remains>30"
--			,"use_item,name=dread_gladiators_badge,if=equipped.161902&cooldown.ca_inc.remains>30"
--			,"use_item,name=azurethos_singed_plumage,if=equipped.161377&cooldown.ca_inc.remains>30"
--			,"use_items,if=cooldown.ca_inc.remains>30"

-- CDs
a.spells["warrior_of_elune"] = {
	ID = 202425--[[Warrior of Elune]],
	CheckFirst = function(z)
		return true
	end,
	FlashColor = "Yellow",
	NoGCD = true,
}

,"innervate,if=azerite.lively_spirit.enabled&(cooldown.incarnation.remains<2|cooldown.celestial_alignment.remains<12)"

a.spells["incarnation,if=astral_power>=40"] = {
	ID = 102560--[[Incarnation: Chosen of Elune]],
	CheckFirst = function(z)
		return x.UseLongCD and x.AstralPower >= 40
	end,
	FlashColor = "Pink",
}

a.spells["celestial_alignment,if=astral_power>=40&(!azerite.lively_spirit.enabled|buff.lively_spirit.up)&(buff.starlord.stack>=2|!talent.starlord.enabled|!variable.az_ss)"] = {
	ID = 194223--[[Celestial Alignment]],
	CheckFirst = function(z)
		return x.UseLongCD and x.AstralPower >= 40 and (not azerite.lively_spirit.enabled or buff.lively_spirit.up) and (buff.starlord.stack >= 2 or not talent.starlord.enabled or not variable.az_ss)
	end,
	FlashColor = "Pink",
}

a.spells["fury_of_elune,if=(buff.ca_inc.up|cooldown.ca_inc.remains>30)&solar_wrath.ap_check"] = {
	ID = 202770--[[Fury of Elune]],
	CheckFirst = function(z)
		return x.UseLongCD and (buff.ca_inc.up or cooldown.ca_inc.remains > 30) and x.AstralPowerDeficit > 8
	end,
	NoRangeCheck = true,
	FlashColor = "Pink",
}

a.spells["force_of_nature,if=(buff.ca_inc.up|cooldown.ca_inc.remains>30)&ap_check"] = {
	ID = 205636--[[Force of Nature]],
	CheckFirst = function(z)
		return x.UseLongCD and (buff.ca_inc.up or cooldown.ca_inc.remains > 30) and x.AstralPowerDeficit > 20
	end,
	NoRangeCheck = true,
	FlashColor = "Pink",
}

-- Spenders
,"cancel_buff,name=starlord,if=buff.starlord.remains<8&!solar_wrath.ap_check"

a.spells["starfall,if=(buff.starlord.stack<3|buff.starlord.remains>=8)&spell_targets>=variable.sf_targets&(target.time_to_die+1)*spell_targets>cost/2.5"] = {
	ID = 191034--[[Starfall]],
	NoRangeCheck = true,
	Check = function(z)
		return (buff.starlord.stack < 3 or buff.starlord.remains >= 8) and x.ActiveEnemies >= variable.sf_targets and (target.time_to_die + 1) * x.ActiveEnemies > s.SpellCost(191034--[[Starfall]]) / 2.5
	end,
}

a.spells["starsurge,if=(talent.starlord.enabled&(buff.starlord.stack<3|buff.starlord.remains>=8&buff.arcanic_pulsar.stack<8)|!talent.starlord.enabled&(buff.arcanic_pulsar.stack<8|buff.ca_inc.up))&spell_targets.starfall<variable.sf_targets&buff.lunar_empowerment.stack+buff.solar_empowerment.stack<4&buff.solar_empowerment.stack<3&buff.lunar_empowerment.stack<3&(!variable.az_ss|!buff.ca_inc.up|!prev.starsurge)|target.time_to_die<=execute_time*astral_power/40|!solar_wrath.ap_check"] = {
	ID = 78674--[[Starsurge]],
	CheckFirst = function(z)
		return (talent.starlord.enabled and (buff.starlord.stack < 3 or buff.starlord.remains >= 8 and buff.arcanic_pulsar.stack < 8) or not talent.starlord.enabled and (buff.arcanic_pulsar.stack < 8 or buff.ca_inc.up)) and x.ActiveEnemies < variable.sf_targets and buff.lunar_empowerment.stack + buff.solar_empowerment.stack < 4 and buff.solar_empowerment.stack < 3 and buff.lunar_empowerment.stack < 3 and (not variable.az_ss or not buff.ca_inc.up or not prev_gcd[1].starsurge) or target.time_to_die <= action.starsurge.execute_time * x.AstralPower / 40 or x.AstralPowerDeficit <= 8
	end,
}

-- DoTs
a.spells["sunfire,target_if=refreshable,if=ap_check&floor(target.time_to_die/tick_time)*spell_targets>=4+spell_targets&(spell_targets>1+talent.twin_moons.enabled|dot.moonfire.ticking)&(!variable.az_ss|!buff.ca_inc.up|!prev.sunfire)"] = {
	ID = 93402--[[Sunfire]],
	CheckFirst = function(z)
		return dot.sunfire.refreshable and x.AstralPowerDeficit > 3 and floor(target.time_to_die / (2 * x.Haste)) * x.ActiveEnemies >= 4 + x.ActiveEnemies and (x.ActiveEnemies > 1 + talent.twin_moons.numeric or dot.moonfire.ticking) and (not variable.az_ss or not buff.ca_inc.up or not prev_gcd[1].sunfire)
	end,
}

a.spells["moonfire,target_if=refreshable,if=ap_check&floor(target.time_to_die/tick_time)*spell_targets>=6&(!variable.az_ss|!buff.ca_inc.up|!prev.moonfire)"] = {
	ID = 8921--[[Moonfire]],
	CheckFirst = function(z)
		return dot.moonfire.refreshable and x.AstralPowerDeficit > 3 and floor(target.time_to_die / (2 * x.Haste)) * x.ActiveEnemies >= 6 and (not variable.az_ss or not buff.ca_inc.up or not prev_gcd[1].moonfire)
	end,
}

a.spells["stellar_flare,target_if=refreshable,if=ap_check&floor(target.time_to_die/tick_time)>=5&(!variable.az_ss|!buff.ca_inc.up|!prev.stellar_flare)"] = {
	ID = 202347--[[Stellar Flare]],
	NotIfActive = true,
	CheckFirst = function(z)
		return dot.stellar_flare.refreshable and x.AstralPowerDeficit > 8 and floor(target.time_to_die/ (2 * x.Haste)) >= 5 and (not variable.az_ss or not buff.ca_inc.up or not prev_gcd[1].stellar_flare)
	end,
}

-- Generators

a.spells["new_moon,if=ap_check"] = {
	ID = 274281--[[New Moon]],
	CheckFirst = function(z)
		return x.AstralPowerDeficit > 10 + action.new_moon.execute_time / 1.5
	end,
}

a.spells["half_moon,if=ap_check"] = {
	ID = 274282--[[Half Moon]],
	CheckFirst = function(z)
		return x.AstralPowerDeficit > 20 + action.half_moon.execute_time / 1.5
	end,
}

a.spells["full_moon,if=ap_check"] = {
	ID = 274283--[[Full Moon]],
	CheckFirst = function(z)
		return x.AstralPowerDeficit > 40 + action.full_moon.execute_time / 1.5
	end,
}

a.spells["lunar_strike,if=buff.solar_empowerment.stack<3&(ap_check|buff.lunar_empowerment.stack=3)&((buff.warrior_of_elune.up|buff.lunar_empowerment.up|spell_targets>=2&!buff.solar_empowerment.up)&(!variable.az_ss|!buff.ca_inc.up|(!prev.lunar_strike&!talent.incarnation.enabled|prev.solar_wrath))|variable.az_ss&buff.ca_inc.up&prev.solar_wrath)"] = {
	ID = 194153--[[Lunar Strike]],
	CheckFirst = function(z)
		return buff.solar_empowerment.stack < 3 and (x.AstralPowerDeficit > 13 or buff.lunar_empowerment.stack == 3) and ((buff.warrior_of_elune.up or buff.lunar_empowerment.up or x.ActiveEnemies >= 2 and not buff.solar_empowerment.up) and (not variable.az_ss or not buff.ca_inc.up or (not prev_gcd[1].lunar_strike and not talent.incarnation.enabled or prev_gcd[1].solar_wrath)) or variable.az_ss and buff.ca_inc.up and prev_gcd[1].solar_wrath)
	end,
}

a.spells["solar_wrath,if=variable.az_ss<3|!buff.ca_inc.up|!prev.solar_wrath"] = {
	ID = 190984--[[Solar Wrath]],
	CheckFirst = function(z)
		return variable.az_ss < 3 or not buff.ca_inc.up or not prev_gcd[1].solar_wrath
	end,
}

-- Fallthru for movement
a.spells["sunfire"] = {
	ID = 93402--[[Sunfire]],
	CheckFirst = function(z)
		return true
	end,
}
