local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables
local buff = x.Buff
local dot = x.Dot
local azerite = x.Azerite

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.EnemyDetected, x.EnemyDetected, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable

-- Example flash color coding:
-- White - Default
-- Yellow - Limited Time or No Global Cooldown
-- Purple - AOE or Positional Damage
-- Blue - AOE Debuff
-- Orange - Finishing Move
-- Aqua - Spell Interrupt, Reflect or Dispel
-- Green - Self Buff or Turn Autocast On
-- Red - Emergency Mitigation Cooldowns or Turn Autocast Off
-- Pink - Optional

a.spells["auto_attack"] = {
	ID = 6603--[[Auto Attack]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	NotIfActive = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.EnemyDetected, "White", "Pink")
		return x.NoCC
	end,
}

a.spells["bear_form"] = {
	Type = "form",
	ID = 5487--[[Bear Form]],
	Buff = 5487--[[Bear Form]],
	BuffUnit = "player",
	FlashColor = "Green",
}

a.spells["wild_charge_bear"] = {
	ID = 16979--[[Wild Charge]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return s.SpellInRange(16979--[[Wild Charge]], "target")
	end,
	FlashColor = "Pink",
}

a.spells["skull_bash"] = {
	ID = 106839--[[Skull Bash]],
	EnemyTargetNeeded = true,
	Interrupt = true,
	NoGCD = true,
	FlashColor = "Aqua",
}

a.spells["growl"] = {
	ID = 6795--[[Growl]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return x.ThreatPercent <= 99 and ( GetNumGroupMembers() > 1 or GetNumSubgroupMembers() > 0 ) and x.EnemyDetected and s.UnitInfo("target") ~= "player" and x.InstanceType ~= "pvp"
	end,
	NoGCD = true,
	FlashColor = "Purple",
}

a.spells["augmentation"] = {
	Type = "item",
	ID = 160053--[[Battle-Scarred Augment Rune]],
	Buff = 270058--[[Battle-Scarred Augmentation]],
	BuffUnit = "player",
	FlashColor = "Green",
	CheckFirst = function(z)
		return s.Boss("target")
	end,
}

a.spells["food"] = {
	Type = "item",
	ID = 156526--[[Bountiful Captain's Feast]],
	Buff = 257415--[[Well Fed]],
	BuffUnit = "player",
	FlashColor = "Green",
	CheckFirst = function(z)
		return s.Boss("target")
	end,
	FlashID = {
		156526--[[Bountiful Captain's Feast]],
		156525--[[Galley Banquet]],
		154884--[[Swamp Fish 'n Chips]],
		154883--[[Ravenberry Tarts]],
		154888--[[Sailor's Pie]],
		154887--[[Loa Loaf]]},
}

a.spells["flask_guardian"] = {
	Type = "item",
	ID = 152638--[[Flask of the Currents]],
	Buff = 251836--[[Flask of the Currents]],
	BuffUnit = "player",
	FlashColor = "Green",
	CheckFirst = function(z)
		return s.Boss("target")
	end,
}

a.spells["potion_guardian"] = {
	Type = "item",
	ID = 152560--[[Potion of Bursting Blood]],
	Buff = 251316--[[Potion of Bursting Blood]],
	BuffUnit = "player",
	NoGCD = true,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.InCombat, "Yellow", "Green")
		return s.Boss("target")
	end,
}

a.spells["berserking"] = {
	ID = 26297--[[Berserking]],
	CheckFirst = function(z)
		return x.UseLongCD
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["barkskin,if=buff.bear_form.up"] = {
	ID = 22812--[[Barkskin]],
	Check = function(z)
		return x.ActiveEnemy and buff.bear_form.up
	end,
	FlashColor = "Yellow",
}

a.spells["lunar_beam,if=buff.bear_form.up"] = {
	ID = 204066--[[Lunar Beam]],
	NoRangeCheck = true,
	Check = function(z)
		return x.ActiveEnemy and buff.bear_form.up
	end,
	FlashColor = "Pink",
	Continue = true,
}

a.spells["bristling_fur,if=buff.bear_form.up"] = {
	ID = 155835--[[Bristling Fur]],
	Check = function(z)
		return x.ActiveEnemy and buff.bear_form.up
	end,
}

a.spells["ironfur,if=buff.ironfur.down&rage>60"] = {
	ID = 192081--[[Ironfur]],
	Buff = 192081--[[Ironfur]],
	BuffUnit = "player",
	CheckFirst = function(z)
		return x.Rage - s.SpellCost(192081--[[Ironfur]]) > s.SpellCost(22842--[[Frenzied Regeneration]])
	end,
	FlashColor = "Yellow",
	NoGCD = true,
}

a.spells["frenzied_regeneration,if=incoming_damage_5s%health.max>=0.5|health<=health.max*0.4"] = {
	ID = 22842--[[Frenzied Regeneration]],
	Buff = 22842--[[Frenzied Regeneration]],
	BuffUnit = "player",
	NoRangeCheck = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and x.Rage >= 10 and (s.IncomingDamage(5000) / x.MaxHealth >= 0.5 or x.Health <= x.MaxHealth * 0.4)
	end,
	FlashColor = "Red",
}

a.spells["maul,if=rage.deficit<10&active_enemies<4"] = {
	ID = 6807--[[Maul]],
	CheckFirst = function(z)
		return (UnitPowerMax("player", Enum.PowerType.Rage) - x.Rage) < 10 and x.ActiveEnemies < 4 and buff.ironfur.up
	end,
	FlashColor = "Pink",
	Continue = true,
}

a.spells["ironfur,if=cost=0|(rage>cost&azerite.layered_mane.enabled&active_enemies>2)"] = {
	ID = 192081--[[Ironfur]],
	CheckFirst = function(z)
		local cost = s.SpellCost(192081--[[Ironfur]])
		return cost == 0 or (x.Rage > cost and azerite.layered_mane.enabled and x.ActiveEnemies > 2)
	end,
	FlashColor = "Yellow",
	NoGCD = true,
}

a.spells["pulverize,target_if=dot.thrash_bear.stack=dot.thrash_bear.max_stacks"] = {
	ID = 80313--[[Pulverize]],
	Check = function(z)
		return dot.thrash_bear.stack == 3
	end,
}

a.spells["moonfire,target_if=dot.moonfire.refreshable&active_enemies<2"] = {
	ID = 8921--[[Moonfire]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return dot.moonfire.refreshable and x.ActiveEnemies < 2
	end,
}

a.spells["incarnation"] = {
	ID = 102558--[[Incarnation: Guardian of Ursoc]],
	CheckFirst = function(z)
		return x.UseLongCD
	end,
}

a.spells["thrash,if=(buff.incarnation.down&active_enemies>1)|(buff.incarnation.up&active_enemies>4)"] = {
	ID = 77758--[[Thrash]],
	NoRangeCheck = true,
	EnemyTargetNeeded = true,
	Melee = true,
	NoPowerCheck = true,
	CheckFirst = function(z)
		return (buff.incarnation.down and x.ActiveEnemies > 1) or (buff.incarnation.up and x.ActiveEnemies > 4)
	end,
}

a.spells["swipe,if=buff.incarnation.down&active_enemies>4"] = {
	ID = 213771--[[Swipe]],
	NoRangeCheck = true,
	EnemyTargetNeeded = true,
	Melee = true,
	NoPowerCheck = true,
	CheckFirst = function(z)
		return buff.incarnation.down and x.ActiveEnemies > 4
	end,
}

a.spells["mangle,if=dot.thrash_bear.ticking"] = {
	ID = 33917--[[Mangle]],
	Check = function(z)
		return dot.thrash_bear.ticking
	end,
}

a.spells["moonfire,target_if=buff.galactic_guardian.up&active_enemies<2"] = {
	ID = 8921--[[Moonfire]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return buff.galactic_guardian.up and x.ActiveEnemies < 2
	end,
}

a.spells["thrash"] = {
	ID = 77758--[[Thrash]],
	NoRangeCheck = true,
	EnemyTargetNeeded = true,
	Melee = true,
	NoPowerCheck = true,
}

a.spells["maul"] = {
	ID = 6807--[[Maul]],
	FlashColor = "Pink",
	Continue = true,
	CheckFirst = function(z)
		return x.Rage - s.SpellCost(6807--[[Maul]]) > s.SpellCost(22842--[[Frenzied Regeneration]]) and buff.ironfur.up
	end,
}

a.spells["swipe"] = {
	ID = 213771--[[Swipe]],
	NoRangeCheck = true,
	EnemyTargetNeeded = true,
	Melee = true,
	NoPowerCheck = true,
}
